# Inject the right home-manager config for the machine.

{ config, pkgs, lib, ... }:

# TODO can we automate the installation of home-manager ?
# sudo nix-channel --add https://github.com/nix-community/home-manager/archive/release-22.11.tar.gz home-manager
{
  imports = [
   <home-manager/nixos>
  ];

  # Let Home Manager install and manage itself.
  #programs.home-manager.enable = true;

  home-manager.users.mrflos = { pkgs, ... }: {
    home.stateVersion = "22.11";    

    accounts.email.accounts = {
      "mrflos@chmok.net" = {
        realName = "Florian Schmitt";
        userName = "mrflos@chmok.net";
        address = "mrflos@chmok.net";

        primary = true;
        thunderbird = {
          enable = true;
        };
        imap = {
          host = "mail.gandi.net";
          port = 143;
          tls.useStartTls = true;
        };

        smtp = {
          host = "mail.gandi.net";
          port = 587;
          tls.useStartTls = true;
        };
      };
    };

    programs.git = {
      enable = true;
      userName = "Florian Schmitt";
      userEmail = "mrflos@gmail.com";
      extraConfig = {
        pull.rebase = true;
        init.defaultBranch = "main";
      };
    };
    
    programs.thunderbird = {
      enable = true;
      profiles.default = {
        isDefault = true;
      };
    };


    gtk = {
      enable = true;

      iconTheme = {
        name = "Papirus-Dark";
        package = pkgs.papirus-icon-theme;
      };

      theme = {
        name = "palenight";
        package = pkgs.palenight-theme;
      };

      cursorTheme = {
        name = "Numix-Cursor";
        package = pkgs.numix-cursor-theme;
      };

      gtk3.extraConfig = {
        Settings = ''
          gtk-application-prefer-dark-theme=1
        '';
      };

      gtk4.extraConfig = {
        Settings = ''
          gtk-application-prefer-dark-theme=1
        '';
      };
    };

    home.sessionVariables.GTK_THEME = "palenight";

  };

  users.users.mrflos = {
    isNormalUser = true;
    description = "mrflos";
    createHome = true;
    extraGroups = [ "docker" "libvirtd" "lxd" "networkmanager" "wheel" ];
    uid = 1000;
    shell = pkgs.zsh;
  };

  nix.settings.trusted-users = [ "mrflos" ];

  home-manager.useGlobalPkgs = true;
}
